## History

### 0.5.0

- Add support for vega visualizations

### 0.4.2

- Fix Add support for terms sorting by custom metric

### 0.4.1

- Fix `format_from_interval` for week intervals

### 0.4.0

- Handle Category axe rotation

### 0.3.1

- Handle ZeroDivisionError in datasweet

### 0.3.0

- Rename `Context` to `Scope`
- Add `BaseDocument.json_attrs` to simplify parsing of some fields (ex: Dashboard.panelsJSON)
- Add datasweet support
- Add support for `using` in client

### 0.2.0

- Add `Search` model
- Add `VegaRenderer` and vega-cli

### 0.1.0

- First version
